## How to build Awex

Please checkout the source tree from https://github.com/inclusionAI/awex.

### Build

### Build Awex Python

```bash
pip install -v -e .
```

#### Environment Requirements

- python 3.8+

### Lint Markdown Docs

```bash
# Install prettier globally
npm install -g prettier

# Fix markdown files
prettier --write "**/*.md"
```

#### Environment Requirements

- node 14+
- npm 8+

## Contributing

For more information, please refer to [How to contribute to Awex](CONTRIBUTING.md).
